﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Net;
using System.Xml;
using System.IO;
using System.ServiceModel;
using System.ServiceModel.Syndication;

namespace DavidAcademyBlogReader
{
    public class MainViewModel : INotifyPropertyChanged
    {
        private const string Url = "http://acad.david.bg/feed";

        public ObservableCollection<ItemViewModel> Items 
        { 
            get; 
            private set; 
        }
        
        public MainViewModel()
        {
            Items = new ObservableCollection<ItemViewModel>();

            var client = new WebClient();
            client.DownloadStringCompleted += new DownloadStringCompletedEventHandler(client_DownloadStringCompleted);
            client.DownloadStringAsync(new Uri(Url));
        }

        void client_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            XmlReader reader = XmlReader.Create(new StringReader(e.Result));
            SyndicationFeed feed = SyndicationFeed.Load(reader);

            foreach (SyndicationItem item in feed.Items)
            {
                Items.Add(new ItemViewModel
                {
                    Title = item.Title.Text,
                    Description = item.Summary.Text,
                    Url = item.Links[0].Uri
                });
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (null != handler)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}